import { Order, Product } from ".";
interface AuthenticationParams {
    username?: string;
    password?: string;
}
interface OrdersPagination {
    start?: number;
    maxOrders?: number;
}
export declare class Hebe {
    private readonly baseUrl;
    token?: string;
    username: string;
    password: string;
    constructor({ username, password }?: AuthenticationParams);
    /**
     * Obtains `this.token` with optionally specified credentials. If not specified, credentials from constructor are to be used.
     *
     * @param authenticationParams - optional, if specified will override set on contructor `this.username` and `this.password`
     */
    authenticate: ({ username, password, }?: AuthenticationParams) => Promise<void>;
    /**
     * Retrieves users orders. Authenticates if not authenticated
     *
     * @param OrdersPagination: optional, if not specified, `maxOrders=100` and `start=0`
     * @returns a list of Order class
     */
    getOrders: ({ maxOrders, start }?: OrdersPagination) => Promise<Order[]>;
    /**
     * Retrieves products for a particular order. Authenticates if not authenticated
     *
     * @param order - instance of an Order class to retrieve the products for
     * @returns a list of Product class instances
     */
    getProducts: (order: Order) => Promise<Product[]>;
    /**
     * Retrieves all products for by default maximum of 100 orders
     *
     * @param params - Orders pagination params, optional.
     * @returns all products for all orders in the account. By default maximum of 100 orders products
     */
    getAllProducts: (params?: OrdersPagination) => Promise<Product[]>;
    private obtainOrders;
    private obtainAuthDwsidToken;
    private obtainInitialToken;
    private get headers();
}
export {};
//# sourceMappingURL=Hebe.d.ts.map